package com.airbnb.lottie.parser;

import android.graphics.PointF;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import androidx.collection.SparseArrayCompat;
import androidx.core.view.animation.PathInterpolatorCompat;
import com.airbnb.lottie.LottieComposition;
import com.airbnb.lottie.parser.moshi.JsonReader;
import com.airbnb.lottie.utils.MiscUtils;
import com.airbnb.lottie.utils.Utils;
import com.airbnb.lottie.value.Keyframe;
import com.amap.api.col.p0003sl.jr;
import java.io.IOException;
import java.lang.ref.WeakReference;

/* loaded from: classes.dex */
class KeyframeParser {
    private static final float MAX_CP_VALUE = 100.0f;
    private static SparseArrayCompat<WeakReference<Interpolator>> pathInterpolatorCache;
    private static final Interpolator LINEAR_INTERPOLATOR = new LinearInterpolator();
    static JsonReader.Options NAMES = JsonReader.Options.of("t", "s", jr.f1343h, "o", "i", jr.f1342g, "to", "ti");

    KeyframeParser() {
    }

    private static SparseArrayCompat<WeakReference<Interpolator>> pathInterpolatorCache() {
        if (pathInterpolatorCache == null) {
            pathInterpolatorCache = new SparseArrayCompat<>();
        }
        return pathInterpolatorCache;
    }

    private static WeakReference<Interpolator> getInterpolator(int i2) {
        WeakReference<Interpolator> weakReference;
        synchronized (KeyframeParser.class) {
            weakReference = pathInterpolatorCache().get(i2);
        }
        return weakReference;
    }

    private static void putInterpolator(int i2, WeakReference<Interpolator> weakReference) {
        synchronized (KeyframeParser.class) {
            pathInterpolatorCache.put(i2, weakReference);
        }
    }

    static <T> Keyframe<T> parse(JsonReader jsonReader, LottieComposition lottieComposition, float f2, ValueParser<T> valueParser, boolean z) throws IOException {
        if (z) {
            return parseKeyframe(lottieComposition, jsonReader, f2, valueParser);
        }
        return parseStaticValue(jsonReader, f2, valueParser);
    }

    private static <T> Keyframe<T> parseKeyframe(LottieComposition lottieComposition, JsonReader jsonReader, float f2, ValueParser<T> valueParser) throws IOException {
        Interpolator interpolator;
        T t;
        Interpolator linearInterpolator;
        jsonReader.beginObject();
        PointF pointF = null;
        PointF pointF2 = null;
        T t2 = null;
        T t3 = null;
        PointF pointF3 = null;
        PointF pointF4 = null;
        float f3 = 0.0f;
        while (true) {
            boolean z = false;
            while (jsonReader.hasNext()) {
                switch (jsonReader.selectName(NAMES)) {
                    case 0:
                        f3 = (float) jsonReader.nextDouble();
                        break;
                    case 1:
                        t3 = valueParser.parse(jsonReader, f2);
                        break;
                    case 2:
                        t2 = valueParser.parse(jsonReader, f2);
                        break;
                    case 3:
                        pointF = JsonUtils.jsonToPoint(jsonReader, f2);
                        break;
                    case 4:
                        pointF2 = JsonUtils.jsonToPoint(jsonReader, f2);
                        break;
                    case 5:
                        if (jsonReader.nextInt() == 1) {
                            z = true;
                            break;
                        }
                        break;
                    case 6:
                        pointF4 = JsonUtils.jsonToPoint(jsonReader, f2);
                        break;
                    case 7:
                        pointF3 = JsonUtils.jsonToPoint(jsonReader, f2);
                        break;
                    default:
                        jsonReader.skipValue();
                        break;
                }
            }
            jsonReader.endObject();
            if (z) {
                interpolator = LINEAR_INTERPOLATOR;
                t = t3;
            } else {
                if (pointF != null && pointF2 != null) {
                    float f4 = -f2;
                    pointF.x = MiscUtils.clamp(pointF.x, f4, f2);
                    pointF.y = MiscUtils.clamp(pointF.y, -100.0f, MAX_CP_VALUE);
                    pointF2.x = MiscUtils.clamp(pointF2.x, f4, f2);
                    pointF2.y = MiscUtils.clamp(pointF2.y, -100.0f, MAX_CP_VALUE);
                    int hashFor = Utils.hashFor(pointF.x, pointF.y, pointF2.x, pointF2.y);
                    WeakReference<Interpolator> interpolator2 = getInterpolator(hashFor);
                    Interpolator interpolator3 = interpolator2 != null ? interpolator2.get() : null;
                    if (interpolator2 == null || interpolator3 == null) {
                        pointF.x /= f2;
                        pointF.y /= f2;
                        pointF2.x /= f2;
                        pointF2.y /= f2;
                        try {
                            linearInterpolator = PathInterpolatorCompat.create(pointF.x, pointF.y, pointF2.x, pointF2.y);
                        } catch (IllegalArgumentException e2) {
                            if (e2.getMessage().equals("The Path cannot loop back on itself.")) {
                                linearInterpolator = PathInterpolatorCompat.create(Math.min(pointF.x, 1.0f), pointF.y, Math.max(pointF2.x, 0.0f), pointF2.y);
                            } else {
                                linearInterpolator = new LinearInterpolator();
                            }
                        }
                        interpolator3 = linearInterpolator;
                        try {
                            putInterpolator(hashFor, new WeakReference(interpolator3));
                        } catch (ArrayIndexOutOfBoundsException unused) {
                        }
                    }
                    interpolator = interpolator3;
                } else {
                    interpolator = LINEAR_INTERPOLATOR;
                }
                t = t2;
            }
            Keyframe<T> keyframe = new Keyframe<>(lottieComposition, t3, t, interpolator, f3, null);
            keyframe.pathCp1 = pointF4;
            keyframe.pathCp2 = pointF3;
            return keyframe;
        }
    }

    private static <T> Keyframe<T> parseStaticValue(JsonReader jsonReader, float f2, ValueParser<T> valueParser) throws IOException {
        return new Keyframe<>(valueParser.parse(jsonReader, f2));
    }
}
