package com.dd.plist;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.facebook.internal.ServerProtocol;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.commons.text.lookup.StringLookupFactory;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/* loaded from: classes.dex */
public class XMLPropertyListParser {
    private static DocumentBuilderFactory docBuilderFactory;

    protected XMLPropertyListParser() {
    }

    private static synchronized void initDocBuilderFactory() {
        synchronized (XMLPropertyListParser.class) {
            DocumentBuilderFactory newInstance = DocumentBuilderFactory.newInstance();
            docBuilderFactory = newInstance;
            newInstance.setIgnoringComments(true);
            docBuilderFactory.setCoalescing(true);
        }
    }

    private static synchronized DocumentBuilder getDocBuilder() throws ParserConfigurationException {
        DocumentBuilder newDocumentBuilder;
        synchronized (XMLPropertyListParser.class) {
            if (docBuilderFactory == null) {
                initDocBuilderFactory();
            }
            newDocumentBuilder = docBuilderFactory.newDocumentBuilder();
            newDocumentBuilder.setEntityResolver(new EntityResolver() { // from class: com.dd.plist.XMLPropertyListParser.1
                @Override // org.xml.sax.EntityResolver
                public InputSource resolveEntity(String str, String str2) {
                    if ("-//Apple Computer//DTD PLIST 1.0//EN".equals(str) || "-//Apple//DTD PLIST 1.0//EN".equals(str)) {
                        return new InputSource(new ByteArrayInputStream(new byte[0]));
                    }
                    return null;
                }
            });
        }
        return newDocumentBuilder;
    }

    public static NSObject parse(File file) throws ParserConfigurationException, IOException, SAXException, PropertyListFormatException, ParseException {
        return parseDocument(getDocBuilder().parse(file));
    }

    public static NSObject parse(byte[] bArr) throws ParserConfigurationException, ParseException, SAXException, PropertyListFormatException, IOException {
        return parse(new ByteArrayInputStream(bArr));
    }

    public static NSObject parse(InputStream inputStream) throws ParserConfigurationException, IOException, SAXException, PropertyListFormatException, ParseException {
        return parseDocument(getDocBuilder().parse(inputStream));
    }

    private static NSObject parseDocument(Document document) throws PropertyListFormatException, IOException, ParseException {
        Node documentElement;
        DocumentType doctype = document.getDoctype();
        if (doctype == null) {
            if (!document.getDocumentElement().getNodeName().equals("plist")) {
                throw new UnsupportedOperationException("The given XML document is not a property list.");
            }
        } else if (!doctype.getName().equals("plist")) {
            throw new UnsupportedOperationException("The given XML document is not a property list.");
        }
        if (document.getDocumentElement().getNodeName().equals("plist")) {
            List<Node> filterElementNodes = filterElementNodes(document.getDocumentElement().getChildNodes());
            if (filterElementNodes.isEmpty()) {
                throw new PropertyListFormatException("The given XML property list has no root element!");
            }
            if (filterElementNodes.size() == 1) {
                documentElement = filterElementNodes.get(0);
            } else {
                throw new PropertyListFormatException("The given XML property list has more than one root element!");
            }
        } else {
            documentElement = document.getDocumentElement();
        }
        return parseObject(documentElement);
    }

    private static NSObject parseObject(Node node) throws ParseException, IOException {
        String nodeName = node.getNodeName();
        int i2 = 0;
        if (nodeName.equals("dict")) {
            NSDictionary nSDictionary = new NSDictionary();
            List<Node> filterElementNodes = filterElementNodes(node.getChildNodes());
            while (i2 < filterElementNodes.size()) {
                nSDictionary.put(getNodeTextContents(filterElementNodes.get(i2)), parseObject(filterElementNodes.get(i2 + 1)));
                i2 += 2;
            }
            return nSDictionary;
        }
        if (nodeName.equals("array")) {
            List<Node> filterElementNodes2 = filterElementNodes(node.getChildNodes());
            NSArray nSArray = new NSArray(filterElementNodes2.size());
            while (i2 < filterElementNodes2.size()) {
                nSArray.setValue(i2, parseObject(filterElementNodes2.get(i2)));
                i2++;
            }
            return nSArray;
        }
        if (nodeName.equals(ServerProtocol.DIALOG_RETURN_SCOPES_TRUE)) {
            return new NSNumber(true);
        }
        if (nodeName.equals("false")) {
            return new NSNumber(false);
        }
        if (nodeName.equals(TypedValues.Custom.S_INT)) {
            return new NSNumber(getNodeTextContents(node));
        }
        if (nodeName.equals("real")) {
            return new NSNumber(getNodeTextContents(node));
        }
        if (nodeName.equals(TypedValues.Custom.S_STRING)) {
            return new NSString(getNodeTextContents(node));
        }
        if (nodeName.equals("data")) {
            return new NSData(getNodeTextContents(node));
        }
        if (nodeName.equals(StringLookupFactory.KEY_DATE)) {
            return new NSDate(getNodeTextContents(node));
        }
        return null;
    }

    private static List<Node> filterElementNodes(NodeList nodeList) {
        ArrayList arrayList = new ArrayList(nodeList.getLength());
        for (int i2 = 0; i2 < nodeList.getLength(); i2++) {
            if (nodeList.item(i2).getNodeType() == 1) {
                arrayList.add(nodeList.item(i2));
            }
        }
        return arrayList;
    }

    private static String getNodeTextContents(Node node) {
        if (node.getNodeType() == 3 || node.getNodeType() == 4) {
            String wholeText = ((Text) node).getWholeText();
            return wholeText == null ? "" : wholeText;
        }
        if (node.hasChildNodes()) {
            NodeList childNodes = node.getChildNodes();
            for (int i2 = 0; i2 < childNodes.getLength(); i2++) {
                Node item = childNodes.item(i2);
                if (item.getNodeType() == 3 || item.getNodeType() == 4) {
                    String wholeText2 = ((Text) item).getWholeText();
                    return wholeText2 == null ? "" : wholeText2;
                }
            }
        }
        return "";
    }
}
