package com.facebook.rebound;

import com.yucheng.smarthealthpro.customchart.utils.Utils;
import java.util.Iterator;
import java.util.concurrent.CopyOnWriteArraySet;

/* loaded from: classes2.dex */
public class Spring {
    private static int ID = 0;
    private static final double MAX_DELTA_TIME_SEC = 0.064d;
    private static final double SOLVER_TIMESTEP_SEC = 0.001d;
    private final PhysicsState mCurrentState;
    private double mEndValue;
    private final String mId;
    private boolean mOvershootClampingEnabled;
    private final PhysicsState mPreviousState;
    private SpringConfig mSpringConfig;
    private final BaseSpringSystem mSpringSystem;
    private double mStartValue;
    private final PhysicsState mTempState;
    private boolean mWasAtRest = true;
    private double mRestSpeedThreshold = 0.005d;
    private double mDisplacementFromRestThreshold = 0.005d;
    private CopyOnWriteArraySet<SpringListener> mListeners = new CopyOnWriteArraySet<>();
    private double mTimeAccumulator = Utils.DOUBLE_EPSILON;

    private static class PhysicsState {
        double position;
        double velocity;

        private PhysicsState() {
        }
    }

    Spring(BaseSpringSystem baseSpringSystem) {
        this.mCurrentState = new PhysicsState();
        this.mPreviousState = new PhysicsState();
        this.mTempState = new PhysicsState();
        if (baseSpringSystem == null) {
            throw new IllegalArgumentException("Spring cannot be created outside of a BaseSpringSystem");
        }
        this.mSpringSystem = baseSpringSystem;
        StringBuilder sb = new StringBuilder("spring:");
        int i2 = ID;
        ID = i2 + 1;
        sb.append(i2);
        this.mId = sb.toString();
        setSpringConfig(SpringConfig.defaultConfig);
    }

    public void destroy() {
        this.mListeners.clear();
        this.mSpringSystem.deregisterSpring(this);
    }

    public String getId() {
        return this.mId;
    }

    public Spring setSpringConfig(SpringConfig springConfig) {
        if (springConfig == null) {
            throw new IllegalArgumentException("springConfig is required");
        }
        this.mSpringConfig = springConfig;
        return this;
    }

    public SpringConfig getSpringConfig() {
        return this.mSpringConfig;
    }

    public Spring setCurrentValue(double d2) {
        return setCurrentValue(d2, true);
    }

    public Spring setCurrentValue(double d2, boolean z) {
        this.mStartValue = d2;
        this.mCurrentState.position = d2;
        this.mSpringSystem.activateSpring(getId());
        Iterator<SpringListener> it2 = this.mListeners.iterator();
        while (it2.hasNext()) {
            it2.next().onSpringUpdate(this);
        }
        if (z) {
            setAtRest();
        }
        return this;
    }

    public double getStartValue() {
        return this.mStartValue;
    }

    public double getCurrentValue() {
        return this.mCurrentState.position;
    }

    public double getCurrentDisplacementDistance() {
        return getDisplacementDistanceForState(this.mCurrentState);
    }

    private double getDisplacementDistanceForState(PhysicsState physicsState) {
        return Math.abs(this.mEndValue - physicsState.position);
    }

    public Spring setEndValue(double d2) {
        if (this.mEndValue == d2 && isAtRest()) {
            return this;
        }
        this.mStartValue = getCurrentValue();
        this.mEndValue = d2;
        this.mSpringSystem.activateSpring(getId());
        Iterator<SpringListener> it2 = this.mListeners.iterator();
        while (it2.hasNext()) {
            it2.next().onSpringEndStateChange(this);
        }
        return this;
    }

    public double getEndValue() {
        return this.mEndValue;
    }

    public Spring setVelocity(double d2) {
        if (d2 == this.mCurrentState.velocity) {
            return this;
        }
        this.mCurrentState.velocity = d2;
        this.mSpringSystem.activateSpring(getId());
        return this;
    }

    public double getVelocity() {
        return this.mCurrentState.velocity;
    }

    public Spring setRestSpeedThreshold(double d2) {
        this.mRestSpeedThreshold = d2;
        return this;
    }

    public double getRestSpeedThreshold() {
        return this.mRestSpeedThreshold;
    }

    public Spring setRestDisplacementThreshold(double d2) {
        this.mDisplacementFromRestThreshold = d2;
        return this;
    }

    public double getRestDisplacementThreshold() {
        return this.mDisplacementFromRestThreshold;
    }

    public Spring setOvershootClampingEnabled(boolean z) {
        this.mOvershootClampingEnabled = z;
        return this;
    }

    public boolean isOvershootClampingEnabled() {
        return this.mOvershootClampingEnabled;
    }

    public boolean isOvershooting() {
        return this.mSpringConfig.tension > Utils.DOUBLE_EPSILON && ((this.mStartValue < this.mEndValue && getCurrentValue() > this.mEndValue) || (this.mStartValue > this.mEndValue && getCurrentValue() < this.mEndValue));
    }

    void advance(double d2) {
        boolean z;
        boolean isAtRest = isAtRest();
        if (isAtRest && this.mWasAtRest) {
            return;
        }
        double d3 = MAX_DELTA_TIME_SEC;
        if (d2 <= MAX_DELTA_TIME_SEC) {
            d3 = d2;
        }
        this.mTimeAccumulator += d3;
        double d4 = this.mSpringConfig.tension;
        double d5 = this.mSpringConfig.friction;
        double d6 = this.mCurrentState.position;
        double d7 = this.mCurrentState.velocity;
        double d8 = this.mTempState.position;
        double d9 = this.mTempState.velocity;
        while (true) {
            double d10 = this.mTimeAccumulator;
            if (d10 < SOLVER_TIMESTEP_SEC) {
                break;
            }
            double d11 = d10 - SOLVER_TIMESTEP_SEC;
            this.mTimeAccumulator = d11;
            if (d11 < SOLVER_TIMESTEP_SEC) {
                this.mPreviousState.position = d6;
                this.mPreviousState.velocity = d7;
            }
            double d12 = this.mEndValue;
            double d13 = ((d12 - d8) * d4) - (d5 * d7);
            double d14 = (d7 * SOLVER_TIMESTEP_SEC * 0.5d) + d6;
            double d15 = d7 + (d13 * SOLVER_TIMESTEP_SEC * 0.5d);
            double d16 = ((d12 - d14) * d4) - (d5 * d15);
            double d17 = d6 + (d15 * SOLVER_TIMESTEP_SEC * 0.5d);
            double d18 = d7 + (d16 * SOLVER_TIMESTEP_SEC * 0.5d);
            double d19 = ((d12 - d17) * d4) - (d5 * d18);
            double d20 = d6 + (d18 * SOLVER_TIMESTEP_SEC);
            double d21 = d7 + (d19 * SOLVER_TIMESTEP_SEC);
            d6 += (d7 + ((d15 + d18) * 2.0d) + d21) * 0.16666666666666666d * SOLVER_TIMESTEP_SEC;
            d7 += (d13 + ((d16 + d19) * 2.0d) + (((d12 - d20) * d4) - (d5 * d21))) * 0.16666666666666666d * SOLVER_TIMESTEP_SEC;
            d8 = d20;
            d9 = d21;
        }
        this.mTempState.position = d8;
        this.mTempState.velocity = d9;
        this.mCurrentState.position = d6;
        this.mCurrentState.velocity = d7;
        double d22 = this.mTimeAccumulator;
        if (d22 > Utils.DOUBLE_EPSILON) {
            interpolate(d22 / SOLVER_TIMESTEP_SEC);
        }
        boolean z2 = true;
        if (isAtRest() || (this.mOvershootClampingEnabled && isOvershooting())) {
            if (d4 > Utils.DOUBLE_EPSILON) {
                double d23 = this.mEndValue;
                this.mStartValue = d23;
                this.mCurrentState.position = d23;
            } else {
                double d24 = this.mCurrentState.position;
                this.mEndValue = d24;
                this.mStartValue = d24;
            }
            setVelocity(Utils.DOUBLE_EPSILON);
            isAtRest = true;
        }
        if (this.mWasAtRest) {
            this.mWasAtRest = false;
            z = true;
        } else {
            z = false;
        }
        if (isAtRest) {
            this.mWasAtRest = true;
        } else {
            z2 = false;
        }
        Iterator<SpringListener> it2 = this.mListeners.iterator();
        while (it2.hasNext()) {
            SpringListener next = it2.next();
            if (z) {
                next.onSpringActivate(this);
            }
            next.onSpringUpdate(this);
            if (z2) {
                next.onSpringAtRest(this);
            }
        }
    }

    public boolean systemShouldAdvance() {
        return (isAtRest() && wasAtRest()) ? false : true;
    }

    public boolean wasAtRest() {
        return this.mWasAtRest;
    }

    public boolean isAtRest() {
        return Math.abs(this.mCurrentState.velocity) <= this.mRestSpeedThreshold && (getDisplacementDistanceForState(this.mCurrentState) <= this.mDisplacementFromRestThreshold || this.mSpringConfig.tension == Utils.DOUBLE_EPSILON);
    }

    public Spring setAtRest() {
        this.mEndValue = this.mCurrentState.position;
        this.mTempState.position = this.mCurrentState.position;
        this.mCurrentState.velocity = Utils.DOUBLE_EPSILON;
        return this;
    }

    private void interpolate(double d2) {
        PhysicsState physicsState = this.mCurrentState;
        double d3 = 1.0d - d2;
        physicsState.position = (physicsState.position * d2) + (this.mPreviousState.position * d3);
        PhysicsState physicsState2 = this.mCurrentState;
        physicsState2.velocity = (physicsState2.velocity * d2) + (this.mPreviousState.velocity * d3);
    }

    public Spring addListener(SpringListener springListener) {
        if (springListener == null) {
            throw new IllegalArgumentException("newListener is required");
        }
        this.mListeners.add(springListener);
        return this;
    }

    public Spring removeListener(SpringListener springListener) {
        if (springListener == null) {
            throw new IllegalArgumentException("listenerToRemove is required");
        }
        this.mListeners.remove(springListener);
        return this;
    }

    public Spring removeAllListeners() {
        this.mListeners.clear();
        return this;
    }

    public boolean currentValueIsApproximately(double d2) {
        return Math.abs(getCurrentValue() - d2) <= getRestDisplacementThreshold();
    }
}
