package com.google.firebase.crashlytics.buildtools.utils.io;

import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.primitives.SignedBytes;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.charset.Charset;

/* loaded from: classes3.dex */
public class ByteReader implements Closeable {
    private static final int BUFFER_SIZE = 64;
    private static final int INT_WIDTH = 4;
    private static final int LONG_WIDTH = 8;
    private static final int SHORT_WIDTH = 2;
    private final ByteBuffer _buffer;
    private final byte[] _bytes;
    private final SeekableInputStream _source;

    public ByteReader(SeekableInputStream seekableInputStream) {
        byte[] bArr = new byte[64];
        this._bytes = bArr;
        this._buffer = ByteBuffer.allocate(bArr.length);
        this._source = seekableInputStream;
    }

    public void seek(long j2) throws IOException {
        this._source.seek(j2);
    }

    public long getCurrentOffset() throws IOException {
        return this._source.getCurrentOffset();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this._source.close();
    }

    public byte readByte() throws IOException {
        int read = this._source.read();
        if (read >= 0) {
            return (byte) (read & 255);
        }
        throw new EOFException();
    }

    public byte[] readBytes(int i2) throws IOException {
        byte[] bArr = new byte[i2];
        this._source.readFully(bArr, 0, i2);
        return bArr;
    }

    public short readShort(int i2) throws IOException {
        ByteBuffer byteBuffer = this._buffer;
        byteBuffer.put(readNumber(this._bytes, i2, 2, byteBuffer.order()));
        short s = this._buffer.getShort();
        return s;
    }

    public int readInt(int i2) throws IOException {
        ByteBuffer byteBuffer = this._buffer;
        byteBuffer.put(readNumber(this._bytes, i2, 4, byteBuffer.order()));
        int i3 = this._buffer.getInt();
        return i3;
    }

    public long readLong(int i2) throws IOException {
        ByteBuffer byteBuffer = this._buffer;
        byteBuffer.put(readNumber(this._bytes, i2, 8, byteBuffer.order()));
        long j2 = this._buffer.getLong();
        return j2;
    }

    public String readNullTerminatedString(Charset charset) throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        while (true) {
            int read = this._source.read();
            if (read == 0) {
                return new String(byteArrayOutputStream.toByteArray(), charset);
            }
            if (read < 0) {
                throw new EOFException();
            }
            byteArrayOutputStream.write(read);
        }
    }

    public int readULEB128() throws IOException {
        int i2 = 0;
        int i3 = 0;
        while (true) {
            byte readByte = readByte();
            i2 |= (readByte & Byte.MAX_VALUE) << i3;
            if ((readByte & 128) == 0) {
                return i2;
            }
            i3 += 7;
        }
    }

    public int readSLEB128() throws IOException {
        byte readByte;
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        do {
            readByte = readByte();
            i2++;
            i3 |= (readByte & Byte.MAX_VALUE) << i4;
            i4 += 7;
        } while ((readByte & 128) != 0);
        return (i4 >= i2 * 8 || (readByte & SignedBytes.MAX_POWER_OF_TWO) == 0) ? i3 : i3 | (-(1 << i4));
    }

    public void setByteOrder(ByteOrder byteOrder) {
        this._buffer.order(byteOrder);
    }

    public ByteOrder getByteOrder() {
        return this._buffer.order();
    }

    private byte[] readNumber(byte[] bArr, int i2, int i3, ByteOrder byteOrder) throws IOException {
        if (i2 > i3) {
            throw new IllegalArgumentException(String.format("Requested number of bytes (%d) was greater than available bytes (%d).", Integer.valueOf(i2), Integer.valueOf(i3)));
        }
        this._source.readFully(bArr, 0, i2);
        return padBytes(bArr, i2, i3, byteOrder);
    }

    private byte[] padBytes(byte[] bArr, int i2, int i3, ByteOrder byteOrder) {
        byte[] bArr2 = new byte[i3];
        System.arraycopy(bArr, 0, bArr2, byteOrder == ByteOrder.BIG_ENDIAN ? i3 - i2 : 0, i2);
        return bArr2;
    }
}
