package com.google.firebase.crashlytics.buildtools.utils.io;

import java.io.EOFException;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;

/* loaded from: classes3.dex */
public class RandomAccessFileInputStream extends SeekableInputStream {
    private static final int BUFFER_SIZE = 8192;
    private byte[] _buffer;
    private RandomAccessFile _file;
    private long _filePointer;
    private int _bufferPos = 0;
    private int _bufferCount = 0;

    public RandomAccessFileInputStream(File file) throws IOException {
        RandomAccessFile randomAccessFile = new RandomAccessFile(file, "r");
        this._file = randomAccessFile;
        this._buffer = new byte[8192];
        this._filePointer = randomAccessFile.getFilePointer();
    }

    @Override // com.google.firebase.crashlytics.buildtools.utils.io.SeekableInputStream
    public void seek(long j2) throws IOException {
        validateOpen();
        if (j2 < 0) {
            throw new IOException("Seek offset must be greater than 0");
        }
        long j3 = this._filePointer;
        long j4 = j3 - this._bufferCount;
        if (j2 >= j4 && j2 < j3) {
            this._bufferPos = (int) (j2 - j4);
            return;
        }
        this._file.seek(j2);
        this._bufferCount = 0;
        this._filePointer = this._file.getFilePointer();
    }

    @Override // com.google.firebase.crashlytics.buildtools.utils.io.SeekableInputStream
    public long getCurrentOffset() throws IOException {
        validateOpen();
        return this._filePointer - Math.max(this._bufferCount - this._bufferPos, 0);
    }

    @Override // com.google.firebase.crashlytics.buildtools.utils.io.SeekableInputStream
    public void readFully(byte[] bArr, int i2, int i3) throws IOException {
        validateOpen();
        int i4 = 0;
        do {
            int read = read(bArr, i2 + i4, i3 - i4);
            if (read < 0) {
                throw new EOFException();
            }
            i4 += read;
        } while (i4 < i3);
    }

    @Override // java.io.InputStream
    public int read() throws IOException {
        validateOpen();
        if (this._bufferPos >= this._bufferCount) {
            fillBuffer();
            if (this._bufferPos >= this._bufferCount) {
                return -1;
            }
        }
        byte[] bArr = this._buffer;
        int i2 = this._bufferPos;
        this._bufferPos = i2 + 1;
        return bArr[i2] & 255;
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr) throws IOException {
        validateOpen();
        return read(bArr, 0, bArr.length);
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) throws IOException {
        int i4;
        if (i2 < 0 || i2 > bArr.length || i3 < 0 || (i4 = i2 + i3) > bArr.length || i4 < 0) {
            throw new IndexOutOfBoundsException();
        }
        if (i3 == 0) {
            return i3;
        }
        validateOpen();
        int i5 = 0;
        do {
            int readOnce = readOnce(bArr, i2 + i5, i3 - i5);
            if (readOnce <= 0) {
                return i5 == 0 ? readOnce : i5;
            }
            i5 += readOnce;
        } while (i5 < i3);
        return i5;
    }

    @Override // java.io.InputStream
    public long skip(long j2) throws IOException {
        if (j2 <= 0) {
            return 0L;
        }
        validateOpen();
        int i2 = this._bufferCount;
        int i3 = this._bufferPos;
        if (j2 <= i2 - i3) {
            this._bufferPos = (int) (i3 + j2);
            return j2;
        }
        long currentOffset = getCurrentOffset();
        long length = this._file.length();
        long j3 = j2 + currentOffset;
        if (j3 <= length) {
            length = j3;
        }
        seek(length);
        return length - currentOffset;
    }

    @Override // java.io.InputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this._file.close();
        this._file = null;
        this._buffer = null;
    }

    private int readOnce(byte[] bArr, int i2, int i3) throws IOException {
        int i4 = this._bufferCount - this._bufferPos;
        if (i4 <= 0) {
            if (i3 >= this._buffer.length) {
                return readFromFile(bArr, i2, i3);
            }
            fillBuffer();
            i4 = this._bufferCount - this._bufferPos;
            if (i4 <= 0) {
                return -1;
            }
        }
        if (i4 < i3) {
            i3 = i4;
        }
        System.arraycopy(this._buffer, this._bufferPos, bArr, i2, i3);
        this._bufferPos += i3;
        return i3;
    }

    private void fillBuffer() throws IOException {
        this._bufferPos = 0;
        this._bufferCount = 0;
        byte[] bArr = this._buffer;
        int readFromFile = readFromFile(bArr, 0, bArr.length);
        if (readFromFile > 0) {
            this._bufferCount = readFromFile;
        }
    }

    private int readFromFile(byte[] bArr, int i2, int i3) throws IOException {
        int read = this._file.read(bArr, i2, i3);
        this._filePointer = this._file.getFilePointer();
        return read;
    }

    private void validateOpen() throws IOException {
        if (this._file == null || this._buffer == null) {
            throw new IOException("Stream closed.");
        }
    }
}
