package com.google.zxing.qrcode.encoder;

import com.dd.plist.ASCIIPropertyListParser;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitArray;
import com.google.zxing.common.ECIEncoderSet;
import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;
import com.google.zxing.qrcode.decoder.Mode;
import com.google.zxing.qrcode.decoder.Version;
import java.lang.reflect.Array;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes3.dex */
final class MinimalEncoder {
    private final ErrorCorrectionLevel ecLevel;
    private final ECIEncoderSet encoders;
    private final boolean isGS1;
    private final String stringToEncode;

    static boolean isNumeric(char c2) {
        return c2 >= '0' && c2 <= '9';
    }

    private enum VersionSize {
        SMALL("version 1-9"),
        MEDIUM("version 10-26"),
        LARGE("version 27-40");

        private final String description;

        VersionSize(String str) {
            this.description = str;
        }

        @Override // java.lang.Enum
        public String toString() {
            return this.description;
        }
    }

    MinimalEncoder(String str, Charset charset, boolean z, ErrorCorrectionLevel errorCorrectionLevel) {
        this.stringToEncode = str;
        this.isGS1 = z;
        this.encoders = new ECIEncoderSet(str, charset, -1);
        this.ecLevel = errorCorrectionLevel;
    }

    static ResultList encode(String str, Version version, Charset charset, boolean z, ErrorCorrectionLevel errorCorrectionLevel) throws WriterException {
        return new MinimalEncoder(str, charset, z, errorCorrectionLevel).encode(version);
    }

    ResultList encode(Version version) throws WriterException {
        if (version != null) {
            ResultList encodeSpecificVersion = encodeSpecificVersion(version);
            if (Encoder.willFit(encodeSpecificVersion.getSize(), getVersion(getVersionSize(encodeSpecificVersion.getVersion())), this.ecLevel)) {
                return encodeSpecificVersion;
            }
            throw new WriterException("Data too big for version" + version);
        }
        Version[] versionArr = {getVersion(VersionSize.SMALL), getVersion(VersionSize.MEDIUM), getVersion(VersionSize.LARGE)};
        ResultList[] resultListArr = {encodeSpecificVersion(versionArr[0]), encodeSpecificVersion(versionArr[1]), encodeSpecificVersion(versionArr[2])};
        int i2 = Integer.MAX_VALUE;
        int i3 = -1;
        for (int i4 = 0; i4 < 3; i4++) {
            int size = resultListArr[i4].getSize();
            if (Encoder.willFit(size, versionArr[i4], this.ecLevel) && size < i2) {
                i3 = i4;
                i2 = size;
            }
        }
        if (i3 < 0) {
            throw new WriterException("Data too big for any version");
        }
        return resultListArr[i3];
    }

    static VersionSize getVersionSize(Version version) {
        return version.getVersionNumber() <= 9 ? VersionSize.SMALL : version.getVersionNumber() <= 26 ? VersionSize.MEDIUM : VersionSize.LARGE;
    }

    static Version getVersion(VersionSize versionSize) {
        int i2 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize[versionSize.ordinal()];
        if (i2 == 1) {
            return Version.getVersionForNumber(9);
        }
        if (i2 == 2) {
            return Version.getVersionForNumber(26);
        }
        return Version.getVersionForNumber(40);
    }

    static boolean isDoubleByteKanji(char c2) {
        return Encoder.isOnlyDoubleByteKanji(String.valueOf(c2));
    }

    static boolean isAlphanumeric(char c2) {
        return Encoder.getAlphanumericCode(c2) != -1;
    }

    /* renamed from: com.google.zxing.qrcode.encoder.MinimalEncoder$1, reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$google$zxing$qrcode$decoder$Mode;
        static final /* synthetic */ int[] $SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize;

        static {
            int[] iArr = new int[Mode.values().length];
            $SwitchMap$com$google$zxing$qrcode$decoder$Mode = iArr;
            try {
                iArr[Mode.KANJI.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$decoder$Mode[Mode.ALPHANUMERIC.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$decoder$Mode[Mode.NUMERIC.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$decoder$Mode[Mode.BYTE.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$decoder$Mode[Mode.ECI.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            int[] iArr2 = new int[VersionSize.values().length];
            $SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize = iArr2;
            try {
                iArr2[VersionSize.SMALL.ordinal()] = 1;
            } catch (NoSuchFieldError unused6) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize[VersionSize.MEDIUM.ordinal()] = 2;
            } catch (NoSuchFieldError unused7) {
            }
            try {
                $SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize[VersionSize.LARGE.ordinal()] = 3;
            } catch (NoSuchFieldError unused8) {
            }
        }
    }

    boolean canEncode(Mode mode, char c2) {
        int i2 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$decoder$Mode[mode.ordinal()];
        if (i2 == 1) {
            return isDoubleByteKanji(c2);
        }
        if (i2 == 2) {
            return isAlphanumeric(c2);
        }
        if (i2 != 3) {
            return i2 == 4;
        }
        return isNumeric(c2);
    }

    static int getCompactedOrdinal(Mode mode) {
        int i2;
        if (mode == null || (i2 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$decoder$Mode[mode.ordinal()]) == 1) {
            return 0;
        }
        if (i2 == 2) {
            return 1;
        }
        if (i2 == 3) {
            return 2;
        }
        if (i2 == 4) {
            return 3;
        }
        throw new IllegalStateException("Illegal mode " + mode);
    }

    void addEdge(Edge[][][] edgeArr, int i2, Edge edge) {
        Edge[] edgeArr2 = edgeArr[i2 + edge.characterLength][edge.charsetEncoderIndex];
        int compactedOrdinal = getCompactedOrdinal(edge.mode);
        Edge edge2 = edgeArr2[compactedOrdinal];
        if (edge2 == null || edge2.cachedTotalSize > edge.cachedTotalSize) {
            edgeArr2[compactedOrdinal] = edge;
        }
    }

    void addEdges(Version version, Edge[][][] edgeArr, int i2, Edge edge) {
        int i3;
        int length = this.encoders.length();
        int priorityEncoderIndex = this.encoders.getPriorityEncoderIndex();
        if (priorityEncoderIndex < 0 || !this.encoders.canEncode(this.stringToEncode.charAt(i2), priorityEncoderIndex)) {
            priorityEncoderIndex = 0;
        } else {
            length = priorityEncoderIndex + 1;
        }
        int i4 = length;
        for (int i5 = priorityEncoderIndex; i5 < i4; i5++) {
            if (this.encoders.canEncode(this.stringToEncode.charAt(i2), i5)) {
                addEdge(edgeArr, i2, new Edge(this, Mode.BYTE, i2, i5, 1, edge, version, null));
            }
        }
        if (canEncode(Mode.KANJI, this.stringToEncode.charAt(i2))) {
            addEdge(edgeArr, i2, new Edge(this, Mode.KANJI, i2, 0, 1, edge, version, null));
        }
        int length2 = this.stringToEncode.length();
        if (canEncode(Mode.ALPHANUMERIC, this.stringToEncode.charAt(i2))) {
            int i6 = i2 + 1;
            addEdge(edgeArr, i2, new Edge(this, Mode.ALPHANUMERIC, i2, 0, (i6 >= length2 || !canEncode(Mode.ALPHANUMERIC, this.stringToEncode.charAt(i6))) ? 1 : 2, edge, version, null));
        }
        if (canEncode(Mode.NUMERIC, this.stringToEncode.charAt(i2))) {
            Mode mode = Mode.NUMERIC;
            int i7 = 0;
            int i8 = i2 + 1;
            if (i8 >= length2 || !canEncode(Mode.NUMERIC, this.stringToEncode.charAt(i8))) {
                i3 = 1;
            } else {
                int i9 = i2 + 2;
                i3 = (i9 >= length2 || !canEncode(Mode.NUMERIC, this.stringToEncode.charAt(i9))) ? 2 : 3;
            }
            addEdge(edgeArr, i2, new Edge(this, mode, i2, i7, i3, edge, version, null));
        }
    }

    ResultList encodeSpecificVersion(Version version) throws WriterException {
        int length = this.stringToEncode.length();
        Edge[][][] edgeArr = (Edge[][][]) Array.newInstance((Class<?>) Edge.class, length + 1, this.encoders.length(), 4);
        addEdges(version, edgeArr, 0, null);
        for (int i2 = 1; i2 <= length; i2++) {
            for (int i3 = 0; i3 < this.encoders.length(); i3++) {
                for (int i4 = 0; i4 < 4; i4++) {
                    Edge edge = edgeArr[i2][i3][i4];
                    if (edge != null && i2 < length) {
                        addEdges(version, edgeArr, i2, edge);
                    }
                }
            }
        }
        int i5 = -1;
        int i6 = Integer.MAX_VALUE;
        int i7 = -1;
        for (int i8 = 0; i8 < this.encoders.length(); i8++) {
            for (int i9 = 0; i9 < 4; i9++) {
                Edge edge2 = edgeArr[length][i8][i9];
                if (edge2 != null && edge2.cachedTotalSize < i6) {
                    i6 = edge2.cachedTotalSize;
                    i5 = i8;
                    i7 = i9;
                }
            }
        }
        if (i5 < 0) {
            throw new WriterException("Internal error: failed to encode \"" + this.stringToEncode + "\"");
        }
        return new ResultList(version, edgeArr[length][i5][i7]);
    }

    private final class Edge {
        private final int cachedTotalSize;
        private final int characterLength;
        private final int charsetEncoderIndex;
        private final int fromPosition;
        private final Mode mode;
        private final Edge previous;

        /* synthetic */ Edge(MinimalEncoder minimalEncoder, Mode mode, int i2, int i3, int i4, Edge edge, Version version, AnonymousClass1 anonymousClass1) {
            this(mode, i2, i3, i4, edge, version);
        }

        private Edge(Mode mode, int i2, int i3, int i4, Edge edge, Version version) {
            this.mode = mode;
            this.fromPosition = i2;
            int i5 = (mode == Mode.BYTE || edge == null) ? i3 : edge.charsetEncoderIndex;
            this.charsetEncoderIndex = i5;
            this.characterLength = i4;
            this.previous = edge;
            boolean z = false;
            int i6 = edge != null ? edge.cachedTotalSize : 0;
            if ((mode == Mode.BYTE && edge == null && i5 != 0) || (edge != null && i5 != edge.charsetEncoderIndex)) {
                z = true;
            }
            i6 = (edge == null || mode != edge.mode || z) ? i6 + mode.getCharacterCountBits(version) + 4 : i6;
            int i7 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$decoder$Mode[mode.ordinal()];
            if (i7 == 1) {
                i6 += 13;
            } else if (i7 == 2) {
                i6 += i4 == 1 ? 6 : 11;
            } else if (i7 == 3) {
                i6 += i4 != 1 ? i4 == 2 ? 7 : 10 : 4;
            } else if (i7 == 4) {
                i6 += MinimalEncoder.this.encoders.encode(MinimalEncoder.this.stringToEncode.substring(i2, i4 + i2), i3).length * 8;
                if (z) {
                    i6 += 12;
                }
            }
            this.cachedTotalSize = i6;
        }
    }

    final class ResultList {
        private final List<ResultNode> list = new ArrayList();
        private final Version version;

        ResultList(Version version, Edge edge) {
            int i2;
            int i3;
            int i4 = 0;
            boolean z = false;
            while (true) {
                i2 = 1;
                if (edge == null) {
                    break;
                }
                int i5 = i4 + edge.characterLength;
                Edge edge2 = edge.previous;
                boolean z2 = (edge.mode == Mode.BYTE && edge2 == null && edge.charsetEncoderIndex != 0) || !(edge2 == null || edge.charsetEncoderIndex == edge2.charsetEncoderIndex);
                z = z2 ? true : z;
                if (edge2 == null || edge2.mode != edge.mode || z2) {
                    this.list.add(0, new ResultNode(edge.mode, edge.fromPosition, edge.charsetEncoderIndex, i5));
                    i5 = 0;
                }
                if (z2) {
                    this.list.add(0, new ResultNode(Mode.ECI, edge.fromPosition, edge.charsetEncoderIndex, 0));
                }
                edge = edge2;
                i4 = i5;
            }
            if (MinimalEncoder.this.isGS1) {
                ResultNode resultNode = this.list.get(0);
                if (resultNode != null && resultNode.mode != Mode.ECI && z) {
                    this.list.add(0, new ResultNode(Mode.ECI, 0, 0, 0));
                }
                this.list.add(this.list.get(0).mode == Mode.ECI ? 1 : 0, new ResultNode(Mode.FNC1_FIRST_POSITION, 0, 0, 0));
            }
            int versionNumber = version.getVersionNumber();
            int i6 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$encoder$MinimalEncoder$VersionSize[MinimalEncoder.getVersionSize(version).ordinal()];
            if (i6 == 1) {
                i3 = 9;
            } else if (i6 != 2) {
                i2 = 27;
                i3 = 40;
            } else {
                i2 = 10;
                i3 = 26;
            }
            int size = getSize(version);
            while (versionNumber < i3 && !Encoder.willFit(size, Version.getVersionForNumber(versionNumber), MinimalEncoder.this.ecLevel)) {
                versionNumber++;
            }
            while (versionNumber > i2 && Encoder.willFit(size, Version.getVersionForNumber(versionNumber - 1), MinimalEncoder.this.ecLevel)) {
                versionNumber--;
            }
            this.version = Version.getVersionForNumber(versionNumber);
        }

        int getSize() {
            return getSize(this.version);
        }

        private int getSize(Version version) {
            Iterator<ResultNode> it2 = this.list.iterator();
            int i2 = 0;
            while (it2.hasNext()) {
                i2 += it2.next().getSize(version);
            }
            return i2;
        }

        void getBits(BitArray bitArray) throws WriterException {
            Iterator<ResultNode> it2 = this.list.iterator();
            while (it2.hasNext()) {
                it2.next().getBits(bitArray);
            }
        }

        Version getVersion() {
            return this.version;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            ResultNode resultNode = null;
            for (ResultNode resultNode2 : this.list) {
                if (resultNode != null) {
                    sb.append(",");
                }
                sb.append(resultNode2.toString());
                resultNode = resultNode2;
            }
            return sb.toString();
        }

        final class ResultNode {
            private final int characterLength;
            private final int charsetEncoderIndex;
            private final int fromPosition;
            private final Mode mode;

            ResultNode(Mode mode, int i2, int i3, int i4) {
                this.mode = mode;
                this.fromPosition = i2;
                this.charsetEncoderIndex = i3;
                this.characterLength = i4;
            }

            /* JADX INFO: Access modifiers changed from: private */
            public int getSize(Version version) {
                int i2 = 4;
                int characterCountBits = this.mode.getCharacterCountBits(version) + 4;
                int i3 = AnonymousClass1.$SwitchMap$com$google$zxing$qrcode$decoder$Mode[this.mode.ordinal()];
                if (i3 != 1) {
                    if (i3 == 2) {
                        int i4 = this.characterLength;
                        return characterCountBits + ((i4 / 2) * 11) + (i4 % 2 == 1 ? 6 : 0);
                    }
                    if (i3 == 3) {
                        int i5 = this.characterLength;
                        characterCountBits += (i5 / 3) * 10;
                        int i6 = i5 % 3;
                        if (i6 != 1) {
                            i2 = i6 == 2 ? 7 : 0;
                        }
                    } else {
                        if (i3 != 4) {
                            return i3 != 5 ? characterCountBits : characterCountBits + 8;
                        }
                        i2 = getCharacterCountIndicator() * 8;
                    }
                } else {
                    i2 = this.characterLength * 13;
                }
                return characterCountBits + i2;
            }

            private int getCharacterCountIndicator() {
                if (this.mode == Mode.BYTE) {
                    ECIEncoderSet eCIEncoderSet = MinimalEncoder.this.encoders;
                    String str = MinimalEncoder.this.stringToEncode;
                    int i2 = this.fromPosition;
                    return eCIEncoderSet.encode(str.substring(i2, this.characterLength + i2), this.charsetEncoderIndex).length;
                }
                return this.characterLength;
            }

            /* JADX INFO: Access modifiers changed from: private */
            public void getBits(BitArray bitArray) throws WriterException {
                bitArray.appendBits(this.mode.getBits(), 4);
                if (this.characterLength > 0) {
                    bitArray.appendBits(getCharacterCountIndicator(), this.mode.getCharacterCountBits(ResultList.this.version));
                }
                if (this.mode == Mode.ECI) {
                    bitArray.appendBits(MinimalEncoder.this.encoders.getECIValue(this.charsetEncoderIndex), 8);
                } else if (this.characterLength > 0) {
                    String str = MinimalEncoder.this.stringToEncode;
                    int i2 = this.fromPosition;
                    Encoder.appendBytes(str.substring(i2, this.characterLength + i2), this.mode, bitArray, MinimalEncoder.this.encoders.getCharset(this.charsetEncoderIndex));
                }
            }

            public String toString() {
                StringBuilder sb = new StringBuilder();
                sb.append(this.mode);
                sb.append(ASCIIPropertyListParser.ARRAY_BEGIN_TOKEN);
                if (this.mode == Mode.ECI) {
                    sb.append(MinimalEncoder.this.encoders.getCharset(this.charsetEncoderIndex).displayName());
                } else {
                    String str = MinimalEncoder.this.stringToEncode;
                    int i2 = this.fromPosition;
                    sb.append(makePrintable(str.substring(i2, this.characterLength + i2)));
                }
                sb.append(ASCIIPropertyListParser.ARRAY_END_TOKEN);
                return sb.toString();
            }

            private String makePrintable(String str) {
                StringBuilder sb = new StringBuilder();
                for (int i2 = 0; i2 < str.length(); i2++) {
                    if (str.charAt(i2) < ' ' || str.charAt(i2) > '~') {
                        sb.append('.');
                    } else {
                        sb.append(str.charAt(i2));
                    }
                }
                return sb.toString();
            }
        }
    }
}
